pub struct Cmyk {
pub cyan: f32,
pub magenta: f32,
pub yellow: f32,
pub key: f32,
}Fields
cyan: f32magenta: f32yellow: f32key: f32Trait Implementations
Sourceimpl DataSize for Cmyk
impl DataSize for Cmyk
Sourceconst IS_DYNAMIC: bool = false
const IS_DYNAMIC: bool = false
If
true, the type has a heap size that can vary at runtime, depending on the actual value.Sourceconst STATIC_HEAP_SIZE: usize = 0usize
const STATIC_HEAP_SIZE: usize = 0usize
The amount of space a value of the type always occupies. If
IS_DYNAMIC is false, this is
the total amount of heap memory occupied by the value. Otherwise this is a lower bound.Sourcefn estimate_heap_size(&self) -> usize
fn estimate_heap_size(&self) -> usize
Estimates the size of heap memory taken up by this value. Read more
impl Copy for Cmyk
impl StructuralPartialEq for Cmyk