#[repr(C, align(8))]pub struct Point {
pub x: f32,
pub y: f32,
}Fields
x: f32y: f32Trait Implementations
Sourceimpl DataSize for Point
impl DataSize for Point
Sourceconst IS_DYNAMIC: bool = false
const IS_DYNAMIC: bool = false
If
true, the type has a heap size that can vary at runtime, depending on the actual value.Sourceconst STATIC_HEAP_SIZE: usize = 0usize
const STATIC_HEAP_SIZE: usize = 0usize
The amount of space a value of the type always occupies. If
IS_DYNAMIC is false, this is
the total amount of heap memory occupied by the value. Otherwise this is a lower bound.Sourcefn estimate_heap_size(&self) -> usize
fn estimate_heap_size(&self) -> usize
Estimates the size of heap memory taken up by this value. Read more
impl Copy for Point
impl StructuralPartialEq for Point