pub struct Rgb {
pub red: f32,
pub green: f32,
pub blue: f32,
}Fields
red: f32green: f32blue: f32Trait Implementations
Sourceimpl DataSize for Rgb
impl DataSize for Rgb
Sourceconst IS_DYNAMIC: bool = false
const IS_DYNAMIC: bool = false
If
true, the type has a heap size that can vary at runtime, depending on the actual value.Sourceconst STATIC_HEAP_SIZE: usize = 0usize
const STATIC_HEAP_SIZE: usize = 0usize
The amount of space a value of the type always occupies. If
IS_DYNAMIC is false, this is
the total amount of heap memory occupied by the value. Otherwise this is a lower bound.Sourcefn estimate_heap_size(&self) -> usize
fn estimate_heap_size(&self) -> usize
Estimates the size of heap memory taken up by this value. Read more
impl Copy for Rgb
impl StructuralPartialEq for Rgb