#[repr(C, align(8))]pub struct ViewRect {
pub x: f32,
pub y: f32,
pub width: f32,
pub height: f32,
}Expand description
ISO 32000-2:2020(E) Table 58 Pg 186 - ViewRect Path construction operators - {x y width height re} Append a rectangle to the current path as a complete subpath, with lower-left corner (x, y) and dimensions width and height in user space.
Fields
x: f32y: f32width: f32height: f32Trait Implementations
Sourceimpl DataSize for ViewRect
impl DataSize for ViewRect
Sourceconst IS_DYNAMIC: bool = false
const IS_DYNAMIC: bool = false
If
true, the type has a heap size that can vary at runtime, depending on the actual value.Sourceconst STATIC_HEAP_SIZE: usize = 0usize
const STATIC_HEAP_SIZE: usize = 0usize
The amount of space a value of the type always occupies. If
IS_DYNAMIC is false, this is
the total amount of heap memory occupied by the value. Otherwise this is a lower bound.Sourcefn estimate_heap_size(&self) -> usize
fn estimate_heap_size(&self) -> usize
Estimates the size of heap memory taken up by this value. Read more
impl Copy for ViewRect
impl StructuralPartialEq for ViewRect