pub struct CCITTFaxDecodeParams {
pub k: i32,
pub end_of_line: bool,
pub encoded_byte_align: bool,
pub columns: u32,
pub rows: u32,
pub end_of_block: bool,
pub black_is_1: bool,
pub damaged_rows_before_error: u32,
}Fields
k: i32end_of_line: boolencoded_byte_align: boolcolumns: u32rows: u32end_of_block: boolblack_is_1: booldamaged_rows_before_error: u32Trait Implementations
Sourceimpl Clone for CCITTFaxDecodeParams
impl Clone for CCITTFaxDecodeParams
Sourcefn clone(&self) -> CCITTFaxDecodeParams
fn clone(&self) -> CCITTFaxDecodeParams
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl DataSize for CCITTFaxDecodeParams
impl DataSize for CCITTFaxDecodeParams
Sourceconst IS_DYNAMIC: bool = false
const IS_DYNAMIC: bool = false
If
true, the type has a heap size that can vary at runtime, depending on the actual value.Sourceconst STATIC_HEAP_SIZE: usize = 0usize
const STATIC_HEAP_SIZE: usize = 0usize
The amount of space a value of the type always occupies. If
IS_DYNAMIC is false, this is
the total amount of heap memory occupied by the value. Otherwise this is a lower bound.Sourcefn estimate_heap_size(&self) -> usize
fn estimate_heap_size(&self) -> usize
Estimates the size of heap memory taken up by this value. Read more
Sourceimpl Debug for CCITTFaxDecodeParams
impl Debug for CCITTFaxDecodeParams
Sourceimpl DeepClone for CCITTFaxDecodeParams
impl DeepClone for CCITTFaxDecodeParams
fn deep_clone(&self, cloner: &mut impl Cloner) -> Result<Self>
Sourceimpl FromDict for CCITTFaxDecodeParams
impl FromDict for CCITTFaxDecodeParams
Sourceimpl Object for CCITTFaxDecodeParams
impl Object for CCITTFaxDecodeParams
Sourceimpl ObjectWrite for CCITTFaxDecodeParams
impl ObjectWrite for CCITTFaxDecodeParams
Sourceimpl ToDict for CCITTFaxDecodeParams
impl ToDict for CCITTFaxDecodeParams