pub struct DCTDecodeParams {
pub color_transform: Option<i32>,
}Fields
color_transform: Option<i32>Trait Implementations
Sourceimpl Clone for DCTDecodeParams
impl Clone for DCTDecodeParams
Sourcefn clone(&self) -> DCTDecodeParams
fn clone(&self) -> DCTDecodeParams
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl DataSize for DCTDecodeParams
impl DataSize for DCTDecodeParams
Sourceconst IS_DYNAMIC: bool = false
const IS_DYNAMIC: bool = false
If
true, the type has a heap size that can vary at runtime, depending on the actual value.Sourceconst STATIC_HEAP_SIZE: usize = 0usize
const STATIC_HEAP_SIZE: usize = 0usize
The amount of space a value of the type always occupies. If
IS_DYNAMIC is false, this is
the total amount of heap memory occupied by the value. Otherwise this is a lower bound.Sourcefn estimate_heap_size(&self) -> usize
fn estimate_heap_size(&self) -> usize
Estimates the size of heap memory taken up by this value. Read more
Sourceimpl Debug for DCTDecodeParams
impl Debug for DCTDecodeParams
Sourceimpl DeepClone for DCTDecodeParams
impl DeepClone for DCTDecodeParams
fn deep_clone(&self, cloner: &mut impl Cloner) -> Result<Self>
Sourceimpl FromDict for DCTDecodeParams
impl FromDict for DCTDecodeParams
Sourceimpl Object for DCTDecodeParams
impl Object for DCTDecodeParams
Sourceimpl ObjectWrite for DCTDecodeParams
impl ObjectWrite for DCTDecodeParams
Sourceimpl ToDict for DCTDecodeParams
impl ToDict for DCTDecodeParams