pub struct Trailer {
pub size: i32,
pub prev_trailer_pos: Option<i32>,
pub root: RcRef<Catalog>,
pub encrypt_dict: Option<RcRef<CryptDict>>,
pub info_dict: Option<InfoDict>,
pub id: Vec<PdfString>,
}Fields
size: i32prev_trailer_pos: Option<i32>root: RcRef<Catalog>encrypt_dict: Option<RcRef<CryptDict>>info_dict: Option<InfoDict>id: Vec<PdfString>Trait Implementations
Sourceimpl DataSize for Trailer
impl DataSize for Trailer
Sourceconst IS_DYNAMIC: bool = true
const IS_DYNAMIC: bool = true
If
true, the type has a heap size that can vary at runtime, depending on the actual value.Sourceconst STATIC_HEAP_SIZE: usize = 0usize
const STATIC_HEAP_SIZE: usize = 0usize
The amount of space a value of the type always occupies. If
IS_DYNAMIC is false, this is
the total amount of heap memory occupied by the value. Otherwise this is a lower bound.Sourcefn estimate_heap_size(&self) -> usize
fn estimate_heap_size(&self) -> usize
Estimates the size of heap memory taken up by this value. Read more
Sourceimpl ObjectWrite for Trailer
impl ObjectWrite for Trailer