pub struct CIDFont {
pub system_info: Dictionary,
pub font_descriptor: FontDescriptor,
pub default_width: f32,
pub widths: Vec<Primitive>,
pub cid_to_gid_map: Option<CidToGidMap>,
pub _other: Dictionary,
}Fields
system_info: Dictionaryfont_descriptor: FontDescriptordefault_width: f32widths: Vec<Primitive>cid_to_gid_map: Option<CidToGidMap>_other: DictionaryTrait Implementations
Sourceimpl DataSize for CIDFont
impl DataSize for CIDFont
Sourceconst IS_DYNAMIC: bool = true
const IS_DYNAMIC: bool = true
If
true, the type has a heap size that can vary at runtime, depending on the actual value.Sourceconst STATIC_HEAP_SIZE: usize = 160usize
const STATIC_HEAP_SIZE: usize = 160usize
The amount of space a value of the type always occupies. If
IS_DYNAMIC is false, this is
the total amount of heap memory occupied by the value. Otherwise this is a lower bound.Sourcefn estimate_heap_size(&self) -> usize
fn estimate_heap_size(&self) -> usize
Estimates the size of heap memory taken up by this value. Read more
Sourceimpl DeepClone for CIDFont
impl DeepClone for CIDFont
fn deep_clone(&self, cloner: &mut impl Cloner) -> Result<Self>
Sourceimpl ObjectWrite for CIDFont
impl ObjectWrite for CIDFont