Font

Struct Font 

pub struct Font {
    pub subtype: FontType,
    pub name: Option<Name>,
    pub data: FontData,
    pub encoding: Option<Encoding>,
    pub to_unicode: Option<RcRef<Stream<()>>>,
    pub _other: Dictionary,
}

Fields

subtype: FontTypename: Option<Name>data: FontDataencoding: Option<Encoding>to_unicode: Option<RcRef<Stream<()>>>_other: Dictionary

other keys not mapped in other places. May change over time without notice, and adding things probably will break things. So don’t expect this to be part of the stable API

Implementations

Source

impl Font

pub fn embedded_data(&self, resolve: &impl Resolve) -> Option<Result<Arc<[u8]>>>

pub fn is_cid(&self) -> bool

pub fn cid_to_gid_map(&self) -> Option<&CidToGidMap>

pub fn encoding(&self) -> Option<&Encoding>

pub fn info(&self) -> Option<&TFont>

pub fn widths(&self, resolve: &impl Resolve) -> Result<Option<Widths>>

pub fn to_unicode(&self, resolve: &impl Resolve) -> Option<Result<ToUnicodeMap>>