pub struct FontStream3 {
pub subtype: FontTypeExt,
}Fields
subtype: FontTypeExtTrait Implementations
Sourceimpl Clone for FontStream3
impl Clone for FontStream3
Sourcefn clone(&self) -> FontStream3
fn clone(&self) -> FontStream3
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl DataSize for FontStream3
impl DataSize for FontStream3
Sourceconst IS_DYNAMIC: bool = true
const IS_DYNAMIC: bool = true
If
true, the type has a heap size that can vary at runtime, depending on the actual value.Sourceconst STATIC_HEAP_SIZE: usize = 0usize
const STATIC_HEAP_SIZE: usize = 0usize
The amount of space a value of the type always occupies. If
IS_DYNAMIC is false, this is
the total amount of heap memory occupied by the value. Otherwise this is a lower bound.Sourcefn estimate_heap_size(&self) -> usize
fn estimate_heap_size(&self) -> usize
Estimates the size of heap memory taken up by this value. Read more
Sourceimpl Debug for FontStream3
impl Debug for FontStream3
Sourceimpl DeepClone for FontStream3
impl DeepClone for FontStream3
fn deep_clone(&self, cloner: &mut impl Cloner) -> Result<Self>
Sourceimpl FromDict for FontStream3
impl FromDict for FontStream3
Sourceimpl Object for FontStream3
impl Object for FontStream3
Sourceimpl ObjectWrite for FontStream3
impl ObjectWrite for FontStream3
Sourceimpl ToDict for FontStream3
impl ToDict for FontStream3