Module object

Module object 

Object trait, along with some implementations. References.

Some of the structs are incomplete (missing fields that are in the PDF references).

Re-exports

pub use crate::file::PromisedRef;

Structs

Annot
AppearanceStreams
Appearance streams for annotations.
Catalog
Dest
EmbeddedFile
PDF Embedded File Stream.
EmbeddedFileParamDict
FieldDictionary
FileSpec
Files
Used only as elements in FileSpec
FormDict
GraphicsStateParameters
ExtGState
IccInfo
ImageDict
A variant of XObject
ImageXObject
InfoDict
InteractiveFormDictionary
InterpolatedFunctionDim
LageLabel
Lazy
MarkInformation
NameDictionary
There is one NameDictionary associated with each PDF file.
NameTree
Note: The PDF concept of ‘root’ node is an intermediate or leaf node which has no ‘Limits’ entry. Hence, limits,
NoResolve
NoUpdate
NumberTree
ObjStmInfo
ObjectStream
OutlineItem
Outlines
Page
PageLabel
PageRc
A PagesNode::Leaf wrapped in a RcRef
PageTree
PagesRc
A PagesNode::Tree wrapped in a RcRef
ParseOptions
PatternDict
PlainRef
PostScriptDict
PsFunc
RcRef
Rectangle
ISO 32000-2:2020(E) 7.9.5 Rectangles (Pg 134) specifying the lower-left x, lower-left y, upper-right x, and upper-right y coordinates of the rectangle, in that order. The other two corners of the rectangle are then assumed to have coordinates (ll x , ur y ) and (ur x , ll y ). Also see Table 74, key BBox definition Pg 221 defining top, left, bottom, right labeling
Ref
Resources
SampledFunction
SeedValueDictionary
SignatureDictionary
SignatureReferenceDictionary
Stream
Simple Stream object with only some additional entries from the stream dict (I).
StreamInfo
General stream type. I is the additional information to be read from the stream dict.
StructElem
StructTreeRoot

Enums

Action
AppearanceStreamEntry
An appearance stream entry can be either:
ColorSpace
Counter
DestView
FieldType
Function
ImageFormat
LineCap
LineJoin
MaybeNamedDest
MaybeRef
NameTreeNode
NumberTreeNode
PagesNode
Node in a page tree - type is either Page or PageTree
Pattern
PostScriptError
PsOp
RenderingIntent
StructType
Trapped
XObject

Traits

Cloner
DeepClone
FromDict
Object
A PDF Object
ObjectWrite
Resolve
SubType
ToDict
Trace
Updater

Type Aliases

GenNr
ObjNr
PostScriptXObject
A variant of XObject
RectDeprecated
Shared