pub struct AdditionalFormActions {
pub mouse_enter: Option<Action>,
pub mouse_exit: Option<Action>,
pub mouse_down: Option<Action>,
pub mouse_up: Option<Action>,
pub input_focus: Option<Action>,
pub input_blur: Option<Action>,
pub page_open: Option<Action>,
pub page_close: Option<Action>,
pub page_visible: Option<Action>,
pub page_invisible: Option<Action>,
}Fields
mouse_enter: Option<Action>mouse_exit: Option<Action>mouse_down: Option<Action>mouse_up: Option<Action>input_focus: Option<Action>input_blur: Option<Action>page_open: Option<Action>page_close: Option<Action>page_visible: Option<Action>page_invisible: Option<Action>Trait Implementations
Sourceimpl Clone for AdditionalFormActions
impl Clone for AdditionalFormActions
Sourcefn clone(&self) -> AdditionalFormActions
fn clone(&self) -> AdditionalFormActions
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl DataSize for AdditionalFormActions
impl DataSize for AdditionalFormActions
Sourceconst IS_DYNAMIC: bool
const IS_DYNAMIC: bool
If
true, the type has a heap size that can vary at runtime, depending on the actual value.Sourceconst STATIC_HEAP_SIZE: usize
const STATIC_HEAP_SIZE: usize
The amount of space a value of the type always occupies. If
IS_DYNAMIC is false, this is
the total amount of heap memory occupied by the value. Otherwise this is a lower bound.Sourcefn estimate_heap_size(&self) -> usize
fn estimate_heap_size(&self) -> usize
Estimates the size of heap memory taken up by this value. Read more
Sourceimpl Debug for AdditionalFormActions
impl Debug for AdditionalFormActions
Sourceimpl DeepClone for AdditionalFormActions
impl DeepClone for AdditionalFormActions
fn deep_clone(&self, cloner: &mut impl Cloner) -> Result<Self>
Sourceimpl Default for AdditionalFormActions
impl Default for AdditionalFormActions
Sourcefn default() -> AdditionalFormActions
fn default() -> AdditionalFormActions
Returns the “default value” for a type. Read more
Sourceimpl FromDict for AdditionalFormActions
impl FromDict for AdditionalFormActions
Sourceimpl Object for AdditionalFormActions
impl Object for AdditionalFormActions
Sourceimpl ObjectWrite for AdditionalFormActions
impl ObjectWrite for AdditionalFormActions
Sourceimpl ToDict for AdditionalFormActions
impl ToDict for AdditionalFormActions