pub struct Annot {Show 13 fields
pub subtype: Name,
pub rect: Option<Rectangle>,
pub contents: Option<PdfString>,
pub page: Option<PageRc>,
pub annotation_name: Option<PdfString>,
pub date: Option<Date>,
pub annot_flags: u32,
pub appearance_streams: Option<MaybeRef<AppearanceStreams>>,
pub appearance_state: Option<Name>,
pub border: Option<Primitive>,
pub color: Option<Primitive>,
pub ink_list: Option<Primitive>,
pub other: Dictionary,
}Fields
subtype: Namerect: Option<Rectangle>contents: Option<PdfString>page: Option<PageRc>annotation_name: Option<PdfString>date: Option<Date>annot_flags: u32appearance_streams: Option<MaybeRef<AppearanceStreams>>appearance_state: Option<Name>border: Option<Primitive>color: Option<Primitive>ink_list: Option<Primitive>other: DictionaryTrait Implementations
Sourceimpl DataSize for Annot
impl DataSize for Annot
Sourceconst IS_DYNAMIC: bool = true
const IS_DYNAMIC: bool = true
If
true, the type has a heap size that can vary at runtime, depending on the actual value.Sourceconst STATIC_HEAP_SIZE: usize = 88usize
const STATIC_HEAP_SIZE: usize = 88usize
The amount of space a value of the type always occupies. If
IS_DYNAMIC is false, this is
the total amount of heap memory occupied by the value. Otherwise this is a lower bound.Sourcefn estimate_heap_size(&self) -> usize
fn estimate_heap_size(&self) -> usize
Estimates the size of heap memory taken up by this value. Read more
Sourceimpl ObjectWrite for Annot
impl ObjectWrite for Annot