pub struct AppearanceStreams {
pub normal: Ref<AppearanceStreamEntry>,
pub rollover: Option<Ref<AppearanceStreamEntry>>,
pub down: Option<Ref<AppearanceStreamEntry>>,
}Fields
normal: Ref<AppearanceStreamEntry>rollover: Option<Ref<AppearanceStreamEntry>>down: Option<Ref<AppearanceStreamEntry>>Trait Implementations
Sourceimpl Clone for AppearanceStreams
impl Clone for AppearanceStreams
Sourcefn clone(&self) -> AppearanceStreams
fn clone(&self) -> AppearanceStreams
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl DataSize for AppearanceStreams
impl DataSize for AppearanceStreams
Sourceconst IS_DYNAMIC: bool = false
const IS_DYNAMIC: bool = false
If
true, the type has a heap size that can vary at runtime, depending on the actual value.Sourceconst STATIC_HEAP_SIZE: usize = 0usize
const STATIC_HEAP_SIZE: usize = 0usize
The amount of space a value of the type always occupies. If
IS_DYNAMIC is false, this is
the total amount of heap memory occupied by the value. Otherwise this is a lower bound.Sourcefn estimate_heap_size(&self) -> usize
fn estimate_heap_size(&self) -> usize
Estimates the size of heap memory taken up by this value. Read more
Sourceimpl Debug for AppearanceStreams
impl Debug for AppearanceStreams
Sourceimpl DeepClone for AppearanceStreams
impl DeepClone for AppearanceStreams
fn deep_clone(&self, cloner: &mut impl Cloner) -> Result<Self>
Sourceimpl FromDict for AppearanceStreams
impl FromDict for AppearanceStreams
Sourceimpl Object for AppearanceStreams
impl Object for AppearanceStreams
Sourceimpl ObjectWrite for AppearanceStreams
impl ObjectWrite for AppearanceStreams
Sourceimpl ToDict for AppearanceStreams
impl ToDict for AppearanceStreams