pub struct FieldDictionary {Show 16 fields
pub typ: Option<FieldType>,
pub parent: Option<Ref<FieldDictionary>>,
pub kids: Vec<Ref<FieldDictionary>>,
pub name: Option<PdfString>,
pub alt_name: Option<PdfString>,
pub mapping_name: Option<PdfString>,
pub flags: u32,
pub sig_flags: u32,
pub value: Primitive,
pub default_value: Primitive,
pub default_resources: Option<MaybeRef<Resources>>,
pub actions: Option<Dictionary>,
pub rect: Option<Rectangle>,
pub max_len: Option<u32>,
pub subtype: Option<Name>,
pub other: Dictionary,
}Fields
typ: Option<FieldType>parent: Option<Ref<FieldDictionary>>kids: Vec<Ref<FieldDictionary>>name: Option<PdfString>alt_name: Option<PdfString>mapping_name: Option<PdfString>flags: u32sig_flags: u32value: Primitivedefault_value: Primitivedefault_resources: Option<MaybeRef<Resources>>actions: Option<Dictionary>rect: Option<Rectangle>max_len: Option<u32>subtype: Option<Name>other: DictionaryTrait Implementations
Sourceimpl Clone for FieldDictionary
impl Clone for FieldDictionary
Sourcefn clone(&self) -> FieldDictionary
fn clone(&self) -> FieldDictionary
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl DataSize for FieldDictionary
impl DataSize for FieldDictionary
Sourceconst IS_DYNAMIC: bool = true
const IS_DYNAMIC: bool = true
If
true, the type has a heap size that can vary at runtime, depending on the actual value.Sourceconst STATIC_HEAP_SIZE: usize = 296usize
const STATIC_HEAP_SIZE: usize = 296usize
The amount of space a value of the type always occupies. If
IS_DYNAMIC is false, this is
the total amount of heap memory occupied by the value. Otherwise this is a lower bound.Sourcefn estimate_heap_size(&self) -> usize
fn estimate_heap_size(&self) -> usize
Estimates the size of heap memory taken up by this value. Read more
Sourceimpl Debug for FieldDictionary
impl Debug for FieldDictionary
Sourceimpl FromDict for FieldDictionary
impl FromDict for FieldDictionary
Sourceimpl Object for FieldDictionary
impl Object for FieldDictionary
Sourceimpl ObjectWrite for FieldDictionary
impl ObjectWrite for FieldDictionary
Sourceimpl ToDict for FieldDictionary
impl ToDict for FieldDictionary