pub struct GraphicsStateParameters {Show 16 fields
pub line_width: Option<f32>,
pub line_cap: Option<LineCap>,
pub line_join: Option<LineJoin>,
pub miter_limit: Option<f32>,
pub dash_pattern: Option<Vec<Primitive>>,
pub rendering_intent: Option<Name>,
pub overprint: Option<bool>,
pub overprint_fill: Option<bool>,
pub overprint_mode: Option<i32>,
pub font: Option<(Ref<Font>, f32)>,
pub blend_mode: Option<Primitive>,
pub smask: Option<Primitive>,
pub stroke_alpha: Option<f32>,
pub fill_alpha: Option<f32>,
pub alpha_is_shape: Option<bool>,
pub text_knockout: Option<bool>,
/* private fields */
}Expand description
ExtGState
Fields
line_width: Option<f32>line_cap: Option<LineCap>line_join: Option<LineJoin>miter_limit: Option<f32>dash_pattern: Option<Vec<Primitive>>rendering_intent: Option<Name>overprint: Option<bool>overprint_fill: Option<bool>overprint_mode: Option<i32>font: Option<(Ref<Font>, f32)>blend_mode: Option<Primitive>smask: Option<Primitive>stroke_alpha: Option<f32>fill_alpha: Option<f32>alpha_is_shape: Option<bool>text_knockout: Option<bool>Trait Implementations
Sourceimpl Clone for GraphicsStateParameters
impl Clone for GraphicsStateParameters
Sourcefn clone(&self) -> GraphicsStateParameters
fn clone(&self) -> GraphicsStateParameters
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl DataSize for GraphicsStateParameters
impl DataSize for GraphicsStateParameters
Sourceconst IS_DYNAMIC: bool = true
const IS_DYNAMIC: bool = true
If
true, the type has a heap size that can vary at runtime, depending on the actual value.Sourceconst STATIC_HEAP_SIZE: usize = 72usize
const STATIC_HEAP_SIZE: usize = 72usize
The amount of space a value of the type always occupies. If
IS_DYNAMIC is false, this is
the total amount of heap memory occupied by the value. Otherwise this is a lower bound.Sourcefn estimate_heap_size(&self) -> usize
fn estimate_heap_size(&self) -> usize
Estimates the size of heap memory taken up by this value. Read more
Sourceimpl Debug for GraphicsStateParameters
impl Debug for GraphicsStateParameters
Sourceimpl DeepClone for GraphicsStateParameters
impl DeepClone for GraphicsStateParameters
fn deep_clone(&self, cloner: &mut impl Cloner) -> Result<Self>
Sourceimpl FromDict for GraphicsStateParameters
impl FromDict for GraphicsStateParameters
Sourceimpl Object for GraphicsStateParameters
impl Object for GraphicsStateParameters
Sourceimpl ToDict for GraphicsStateParameters
impl ToDict for GraphicsStateParameters