pub struct IccInfo {
pub components: u32,
pub alternate: Option<Box<ColorSpace>>,
pub range: Option<Vec<f32>>,
pub metadata: Option<Stream<()>>,
}Fields
components: u32alternate: Option<Box<ColorSpace>>range: Option<Vec<f32>>metadata: Option<Stream<()>>Trait Implementations
Sourceimpl DataSize for IccInfo
impl DataSize for IccInfo
Sourceconst IS_DYNAMIC: bool = true
const IS_DYNAMIC: bool = true
If
true, the type has a heap size that can vary at runtime, depending on the actual value.Sourceconst STATIC_HEAP_SIZE: usize = 0usize
const STATIC_HEAP_SIZE: usize = 0usize
The amount of space a value of the type always occupies. If
IS_DYNAMIC is false, this is
the total amount of heap memory occupied by the value. Otherwise this is a lower bound.Sourcefn estimate_heap_size(&self) -> usize
fn estimate_heap_size(&self) -> usize
Estimates the size of heap memory taken up by this value. Read more
Sourceimpl DeepClone for IccInfo
impl DeepClone for IccInfo
fn deep_clone(&self, cloner: &mut impl Cloner) -> Result<Self>
Sourceimpl ObjectWrite for IccInfo
impl ObjectWrite for IccInfo