pub struct PlainRef {
pub id: ObjNr,
pub gen: GenNr,
}Fields
id: ObjNrgen: GenNrTrait Implementations
Sourceimpl DataSize for PlainRef
impl DataSize for PlainRef
Sourceconst IS_DYNAMIC: bool = false
const IS_DYNAMIC: bool = false
If
true, the type has a heap size that can vary at runtime, depending on the actual value.Sourceconst STATIC_HEAP_SIZE: usize = 0usize
const STATIC_HEAP_SIZE: usize = 0usize
The amount of space a value of the type always occupies. If
IS_DYNAMIC is false, this is
the total amount of heap memory occupied by the value. Otherwise this is a lower bound.Sourcefn estimate_heap_size(&self) -> usize
fn estimate_heap_size(&self) -> usize
Estimates the size of heap memory taken up by this value. Read more
Sourceimpl DeepClone for PlainRef
impl DeepClone for PlainRef
fn deep_clone(&self, cloner: &mut impl Cloner) -> Result<Self>
Sourceimpl ObjectWrite for PlainRef
impl ObjectWrite for PlainRef
impl Copy for PlainRef
impl Eq for PlainRef
impl StructuralPartialEq for PlainRef