pub struct Rectangle {
pub left: f32,
pub bottom: f32,
pub right: f32,
pub top: f32,
}Expand description
ISO 32000-2:2020(E) 7.9.5 Rectangles (Pg 134) specifying the lower-left x, lower-left y, upper-right x, and upper-right y coordinates of the rectangle, in that order. The other two corners of the rectangle are then assumed to have coordinates (ll x , ur y ) and (ur x , ll y ). Also see Table 74, key BBox definition Pg 221 defining top, left, bottom, right labeling
Fields
left: f32bottom: f32right: f32top: f32Trait Implementations
Sourceimpl DataSize for Rectangle
impl DataSize for Rectangle
Sourceconst IS_DYNAMIC: bool = false
const IS_DYNAMIC: bool = false
If
true, the type has a heap size that can vary at runtime, depending on the actual value.Sourceconst STATIC_HEAP_SIZE: usize = 0usize
const STATIC_HEAP_SIZE: usize = 0usize
The amount of space a value of the type always occupies. If
IS_DYNAMIC is false, this is
the total amount of heap memory occupied by the value. Otherwise this is a lower bound.Sourcefn estimate_heap_size(&self) -> usize
fn estimate_heap_size(&self) -> usize
Estimates the size of heap memory taken up by this value. Read more
Sourceimpl DeepClone for Rectangle
impl DeepClone for Rectangle
fn deep_clone(&self, cloner: &mut impl Cloner) -> Result<Self>
Sourceimpl ObjectWrite for Rectangle
impl ObjectWrite for Rectangle
impl Copy for Rectangle