pub struct Stream<I> {
pub info: StreamInfo<I>,
/* private fields */
}Expand description
Simple Stream object with only some additional entries from the stream dict (I).
Fields
info: StreamInfo<I>Implementations
Sourceimpl<I: Object> Stream<I>
impl<I: Object> Stream<I>
pub fn from_stream(s: PdfStream, resolve: &impl Resolve) -> Result<Self>
Sourcepub fn new_with_filters(
i: I,
data: impl Into<Arc<[u8]>>,
filters: Vec<StreamFilter>,
) -> Stream<I>
pub fn new_with_filters( i: I, data: impl Into<Arc<[u8]>>, filters: Vec<StreamFilter>, ) -> Stream<I>
the data is not compressed. the specified filters are to be applied when compressing the data
pub fn new(i: I, data: impl Into<Arc<[u8]>>) -> Stream<I>
Sourcepub fn from_compressed(
i: I,
data: impl Into<Arc<[u8]>>,
filters: Vec<StreamFilter>,
) -> Stream<I>
pub fn from_compressed( i: I, data: impl Into<Arc<[u8]>>, filters: Vec<StreamFilter>, ) -> Stream<I>
the data is already compressed with the specified filters
pub fn data(&self, resolve: &impl Resolve) -> Result<Arc<[u8]>>
pub fn len(&self) -> usize
Sourceimpl<I: ObjectWrite> Stream<I>
impl<I: ObjectWrite> Stream<I>
pub fn to_pdf_stream(&self, update: &mut impl Updater) -> Result<PdfStream>
Methods from Deref<Target = StreamInfo<I>>
pub fn get_filters(&self) -> &[StreamFilter]