StreamInfo

Struct StreamInfo 

pub struct StreamInfo<I> {
    pub filters: Vec<StreamFilter>,
    pub file: Option<FileSpec>,
    pub file_filters: Vec<StreamFilter>,
    pub info: I,
}
General stream type. I is the additional information to be read from the stream dict.

Fields

filters: Vec<StreamFilter>

Filters that the data is currently encoded with (corresponds to both /Filter and /DecodeParms in the PDF specs), constructed in from_primitive().

file: Option<FileSpec>

Eventual file containing the stream contentst

file_filters: Vec<StreamFilter>

Filters to apply to external file specified in file.

info: I

Implementations

Source

impl<T> StreamInfo<T>

pub fn get_filters(&self) -> &[StreamFilter]