pub struct StructElem {
pub struct_type: StructType,
pub parent: Ref<StructElem>,
pub id: Option<PdfString>,
pub page: Option<Ref<Page>>,
}Fields
struct_type: StructTypeparent: Ref<StructElem>id: Option<PdfString>page: Option<Ref<Page>>Pg: A page object representing a page on which some or all of the content items designated by the K entry are rendered.