pub struct StructTreeRoot {
pub children: Vec<StructElem>,
}Fields
children: Vec<StructElem>Trait Implementations
Sourceimpl DataSize for StructTreeRoot
impl DataSize for StructTreeRoot
Sourceconst IS_DYNAMIC: bool = true
const IS_DYNAMIC: bool = true
If
true, the type has a heap size that can vary at runtime, depending on the actual value.Sourceconst STATIC_HEAP_SIZE: usize = 0usize
const STATIC_HEAP_SIZE: usize = 0usize
The amount of space a value of the type always occupies. If
IS_DYNAMIC is false, this is
the total amount of heap memory occupied by the value. Otherwise this is a lower bound.Sourcefn estimate_heap_size(&self) -> usize
fn estimate_heap_size(&self) -> usize
Estimates the size of heap memory taken up by this value. Read more
Sourceimpl Debug for StructTreeRoot
impl Debug for StructTreeRoot
Sourceimpl FromDict for StructTreeRoot
impl FromDict for StructTreeRoot
Sourceimpl Object for StructTreeRoot
impl Object for StructTreeRoot
Sourceimpl ObjectWrite for StructTreeRoot
impl ObjectWrite for StructTreeRoot
Sourceimpl ToDict for StructTreeRoot
impl ToDict for StructTreeRoot