StringLexer

Struct StringLexer 

pub struct StringLexer<'a> { /* private fields */ }
A lexer for PDF strings. Breaks the string up into single characters (u8) It’s also possible to get the number of indices of the original array that was traversed by the Iterator.

let mut string: Vec<u8> = Vec::new();
let bytes_traversed = {
    let mut string_lexer = StringLexer::new(lexer.get_remaining_slice());
    for character in string_lexer.iter() {
        let character = character?;
        string.push(character);
    }
    string_lexer.get_offset() as i64
};
// bytes_traversed now holds the number of bytes in the original array traversed.

Implementations

Source

impl<'a> StringLexer<'a>

pub fn new(buf: &'a [u8]) -> StringLexer<'a>

buf should start right after the ( delimiter, and may span all the way to EOF. StringLexer will determine the end of the string.

pub fn iter<'b>(&'b mut self) -> StringLexerIter<'a, 'b>

pub fn get_offset(&self) -> usize

Get offset/pos from start of string

pub fn next_lexeme(&mut self) -> Result<Option<u8>>

(mostly just used by Iterator, but might be useful)