pub struct Date {
pub year: u16,
pub month: u8,
pub day: u8,
pub hour: u8,
pub minute: u8,
pub second: u8,
pub rel: TimeRel,
pub tz_hour: u8,
pub tz_minute: u8,
}Fields
year: u16month: u8day: u8hour: u8minute: u8second: u8rel: TimeReltz_hour: u8tz_minute: u8Trait Implementations
Sourceimpl DataSize for Date
impl DataSize for Date
Sourceconst IS_DYNAMIC: bool = false
const IS_DYNAMIC: bool = false
If
true, the type has a heap size that can vary at runtime, depending on the actual value.Sourceconst STATIC_HEAP_SIZE: usize = 10usize
const STATIC_HEAP_SIZE: usize = 10usize
The amount of space a value of the type always occupies. If
IS_DYNAMIC is false, this is
the total amount of heap memory occupied by the value. Otherwise this is a lower bound.Sourcefn estimate_heap_size(&self) -> usize
fn estimate_heap_size(&self) -> usize
Estimates the size of heap memory taken up by this value. Read more
Sourceimpl ObjectWrite for Date
impl ObjectWrite for Date
impl Eq for Date
impl StructuralPartialEq for Date