PdfString

Struct PdfString 

pub struct PdfString {
    pub data: IBytes,
}
Primitive String type.

Fields

data: IBytes

Implementations

Source

impl PdfString

pub fn serialize(&self, out: &mut impl Write) -> Result<()>

Source

impl PdfString

pub fn new(data: IBytes) -> PdfString

pub fn as_bytes(&self) -> &[u8]

pub fn into_bytes(self) -> IBytes

pub fn to_string_lossy(&self) -> String

without encoding information the PdfString cannot be decoded into a String therefore only lossy decoding is possible replacing unknown characters. For decoding correctly see pdf_tools/src/lib.rs

pub fn to_string(&self) -> Result<String>

without encoding information the PdfString cannot be sensibly decoded into a String converts to a Rust String but only works for valid UTF-8, UTF-16BE and ASCII characters if invalid bytes found an Error is returned